/***********************************************************************************************************
The Unintended Impacts of an Intimate Partner Violence Prevention Program: Experimental Evidence from Rwanda
REPLICATION FILE 2 - PAPER TABLES AND FIGURES

Prepared by: Ludovic Bequet 12 December 2024
Stata version: 15.1
************************************************************************************************************/

clear
set more off
cap log close 

use "$data/indash_vsla_final.dta", clear
xtset strata	

*** Table 1: Treatment effects on primary IPV outcomes

	foreach var in $ipv {
		eststo clear
		des `var'
		eststo xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata, vce(cluster village_id_m_bl)	  
			lincom couple_treat - spillover_couple			
			local	difpval1=	r(p)
			sum `var' if couple_type==0
			local contmean1 = r(mean) 
			test couple_treat
			local ptreat`var' = r(p)
			test spillover_couple
			local pspill`var' = r(p)
			outreg2  using "$out/tables/table1.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
				adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES) ///
				keep(couple_treat spillover_couple) nonotes
			}
*** Sharpened q-values 
preserve
	clear 
		set obs 6
		quietly gen float pval = .
		replace pval = `ptreatemo_violence_dum' in 1
		replace pval = `pspillemo_violence_dum' in 2
		replace pval = `ptreatphysical_violence_dum' in 3
		replace pval = `pspillphysical_violence_dum' in 4
		replace pval = `ptreatsexual_violence_dum' in 5
		replace pval = `pspillsexual_violence_dum' in 6

	* Collect the total number of p-values tested

	quietly sum pval
	local totalpvals = r(N)

	* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

	quietly gen int original_sorting_order = _n
	quietly sort pval
	quietly gen int rank = _n if pval~=.

	* Set the initial counter to 1 

	local qval = 1

	* Generate the variable that will contain the BKY (2006) sharpened q-values

	gen bky06_qval = 1 if pval~=.

	* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


	while `qval' > 0 {
		* First Stage
		* Generate the adjusted first stage q level we are testing: q' = q/1+q
		local qval_adj = `qval'/(1+`qval')
		* Generate value q'*r/M
		gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
		* Generate binary variable checking condition p(r) <= q'*r/M
		gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
		* Generate variable containing p-value ranks for all p-values that meet above condition
		gen reject_rank1 = reject_temp1*rank
		* Record the rank of the largest p-value that meets above condition
		egen total_rejected1 = max(reject_rank1)

		* Second Stage
		* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
		local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
		* Generate value q_2st*r/M
		gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
		* Generate binary variable checking condition p(r) <= q_2st*r/M
		gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
		* Generate variable containing p-value ranks for all p-values that meet above condition
		gen reject_rank2 = reject_temp2*rank
		* Record the rank of the largest p-value that meets above condition
		egen total_rejected2 = max(reject_rank2)

		* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
		replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
		* Reduce q by 0.001 and repeat loop
		drop fdr_temp* reject_temp* reject_rank* total_rejected*
		local qval = `qval' - .001
	}
		

	quietly sort original_sorting_order
	pause off
	set more on

	display "Code has completed."
	display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
	display	"Sorting order is the same as the original vector of p-values"
	
	label define original_sorting_order 1 "Emotional treated" 2 "Emotional spillover" 3 "Physical treated" 4 "Physical spillover" 5 "Sexual treated" 6 "Sexual spillover"
	label values original_sorting_order original_sorting_order
	list original_sorting_order bky06_qval
	* Note: Sharpened FDR q-vals can be LESS than unadjusted p-vals when many hypotheses are rejected, because if you have many true rejections, then you can tolerate several false rejections too (this effectively just happens for p-vals that are so large that you are not going to reject them regardless).
restore 

*** Table 2: Treatment effects on other wellbeing and relationship quality indicators
	local sec_out WeightedVar_relqual_w WeightedVar_relqual_m WeightedVar_dep_w WeightedVar_dep_m escalate_physical_w drink_quarrel_w husb_takemoney_hhben_w spouse_cheat_w
	foreach var in `sec_out' {
		eststo clear
		eststo xi: qui reg `var' couple_treat spillover_couple i.strata, vce(cluster village_id_m_bl)	  
			lincom couple_treat - spillover_couple		
			local	difpval1=	r(p)
			sum `var' if couple_type==0
			local contmean1 = r(mean) 
			outreg2  using "$out/tables/table2.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, NO) ///
			keep(couple_treat spillover_couple) nonotes
			}


*** Table 3: Backlash mechanisms: Behaviors
	local meca_behaviora ptnr_drnktoomuch_w alc_excess_m
	local meca_behaviorb alcohol_daily_m_ful formalized_marr_w_blel husb_takemoney_hhben_w domestic_care_mins_w domestic_care_mins_m
		foreach var in `meca_behaviora' {
		eststo clear		
		eststo: xi: qui reg  `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table3.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, YES) ///
			 keep(couple_treat spillover_couple) nonotes
	}

		foreach var in `meca_behaviorb' {
		eststo clear		
		eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table3.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes
			}


*** Table 4: Backlash mechanisms: Agency and decision making
	local meca_agencya wantmre_dec_idl_hhexpns_w wantmre_dec_idl_chldbr_w dec_input_inc_w_role dec_input_hh_inc_w_role dec_input_hh_exp_w_role dec_input_child_w_role
	local meca_agencyb wantmre_dec_idl_hhexpns_m wantmre_dec_idl_chldbr_m dec_input_inc_m_role  dec_input_hh_inc_m_role dec_input_hh_exp_m_role dec_input_child_m_role
		foreach var in `meca_agencya' {
		eststo clear		
		eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table4a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes
			}
		foreach var in `meca_agencyb' {
		eststo clear		
		eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table4b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes
			}

*** Table 5: Backlash mechanisms: Gender attitudes
	local meca_attitudesa own_gendernorms_w own_ipv_justified_w own_refusesex_w  
	local meca_attitudesb own_gendernorms_m own_ipv_justified_m own_refusesex_m reasons_lklyvio_m_eg  
	local meca_attitudesc gap_gndrnrms gap_ipvjust 
		foreach var in `meca_attitudesa' {
		eststo clear		
		eststo: xi: qui reg  `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table5a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES) ///
			  keep(couple_treat spillover_couple) nonotes
	}
		foreach var in `meca_attitudesb' {
		eststo clear		
		eststo: xi: qui reg  `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table5b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES) ///
			  keep(couple_treat spillover_couple) nonotes
	}
		foreach var in `meca_attitudesc' {
		eststo clear		
		eststo: xi: qui reg  `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table5c.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES) ///
			  keep(couple_treat spillover_couple) nonotes
	}

		eststo clear		
		eststo: xi: qui reg  wifegtmoreprog_ipvjust_dum couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum wifegtmoreprog_ipvjust_dum if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/table5c.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes



*** Figure 1: Primary outcome variables ***
foreach var in $ipv {
	eststo clear
	eststo xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata, vce(cluster village_id_m_bl)	  
	est store reg_`var'
}
label var couple_treat "Treated"
label var spillover_couple "Spillover"
coefplot (reg_emo_violence_dum, asequation("Emotional IPV") \ reg_physical_violence_dum, asequation("Physical IPV") ///
	 \ reg_sexual_violence_dum, asequation("Sexual IPV") keep(couple_treat spillover_couple) graphregion(color(white)))|| , ///
 	 xline(0) yscale(range(-4 `=6+4')) mlabel format(%9.2f) mlabposition(12) mlabgap(*2) eqlabels("{bf:Emotional IPV}" "{bf:Physical IPV}" ///
 	 	"{bf:Sexual IPV}", ashead)
graph export "$out/figures\figure1.png", replace 


*** Figure 3: Agency and sole decision maker
foreach var in dec_input_inc_m_role  dec_input_hh_inc_m_role dec_input_hh_exp_m_role dec_input_child_m_role {
	eststo clear		
	eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
	est store reg_`var'
}

coefplot reg_dec_input_inc_m_role, bylabel("Income") || reg_dec_input_hh_inc_m_role, bylabel("Household income") || ///
 	 reg_dec_input_hh_exp_m_role, bylabel("Major HH expenses") || reg_dec_input_child_m_role, bylabel("Childbearing") || , ///
 	 yline(0) keep(couple_treat spillover_couple) vert subtitle(,bcolor(white)) bycoef xlabel(, angle(45))
	graph export "$out/figures\figure3.png", replace 

*** Figure 4: Frictions  ***
foreach var in gap_gndrnrms gap_ipvjust {
	eststo clear		
	eststo: xi: qui reg  `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
	est store reg_`var'
}
coefplot (reg_gap_gndrnrms, asequation("Diff. inequitable attitudes") \ reg_gap_ipvjust, asequation("Diff. IPV acceptability") ///
	 keep(couple_treat spillover_couple) graphregion(color(white)))|| , xline(0) yscale(range(-4 `=4+4')) ///
	mlabel format(%9.2f) mlabposition(12) mlabgap(*2) eqlabels("{bf:Husband inequitable attitude – Wife inequitable attitude}" ///
	"{bf:Husband IPV acceptability– Wife IPV acceptability}", ashead)
	graph export "$out/figures\figure4.png", replace 


*** Figure 5: Agency aspirations ***
rename wantmre_dec_idl_hhexpns_w wantmre_hhexpns_w
rename wantmre_dec_idl_chldbr_w wantmre_chldbr_w
rename wantmre_dec_idl_hhexpns_m wantmre_hhexpns_m
rename wantmre_dec_idl_chldbr_m wantmre_chldbr_m
foreach var in wantmre_hhexpns_w wantmre_chldbr_w wantmre_hhexpns_m wantmre_chldbr_m {
	eststo clear		
	eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
	est store reg_`var'
}

grstyle init
grstyle color background white 
coefplot (reg_wantmre_hhexpns_m, label(Men) msymbol(D)) (reg_wantmre_hhexpns_w, label(Women) msymbol(S) mcolor(navy) ciopts(color(navy))) || ///
	, keep(couple_treat spillover_couple) graphregion(color(white)) xline(0) yscale(range(-2 `=1+2')) ///
	mlabel format(%9.2f) mlabposition(12) mlabgap(*2) mlabcolor(navy)
	graph export "$out/figures\figure5.png", replace 







*** Table A2: Balance test comparing village sample and VSLA sample
preserve
	use "$data/indash_community_final.dta", clear
	label var emo_violence_dum_bl "Any emotional violence in last 12m"
	label var physical_violence_dum_bl "Any physical violence in last 12m"
	label var sexual_violence_dum_bl "Any sexual violence in last 12m"
	label var own_ipv_justified_w_bl "No. of reasons IPV is justified" 
	label var own_ipv_justified_m_bl "No. of reasons IPV is justified"
	label var own_gendernorms_w_bl "No. of gender inequitable attitudes"
	label var own_gendernorms_m_bl "No of gender inequitable attitudes"
	label var d8_age_years_w_bl "Age"
	label var e10_age_years_m_bl "Age"
	label var e11_education_w_bl_clean "Years of education"
	label var e29_education_m_bl_clean "Years of education" 
	label var civil_legal_marriage_bl "In a civil or legal marriage" 
	label var g1_meals_skipped_m_bl "A member of hh skipped a meal in the last week"
	label var cmty_beat_wife_low_bl "Thinks at most 25pc of men beat up wife"
	label var cmty_force_sex_low_bl "Thinks at most 25pc of men force wife to have sex"
	label var e12_n_bio_children_w_bl "No. of children"
	
	local balance emo_violence_dum_bl physical_violence_dum_bl sexual_violence_dum_bl d8_age_years_w_bl e11_education_w_bl_clean e12_n_bio_children_w_bl own_ipv_justified_w_bl own_gendernorms_w_bl e10_age_years_m_bl e29_education_m_bl_clean own_ipv_justified_m_bl own_gendernorms_m_bl cmty_beat_wife_low_bl cmty_force_sex_low_bl civil_legal_marriage_bl g1_meals_skipped_m_bl

	iebaltab `balance' , grpvar(a12_couples_survey_w_bl) savetex("$out/tables\tablea2.tex") replace ///
	rowvarlabel stats(pair(t)) format(%9.2fc)  vce(cluster village_id_m_num) fixedeffect(strata) ///
	tblnonote 

restore

*** Table A3: Baseline Sample Characteristics and Balance across 3 groups

label var emo_violence_dum_bl "Any emotional violence in last 12m"
label var physical_violence_dum_bl "Any physical violence in last 12m"
label var sexual_violence_dum_bl "Any sexual violence in last 12m"
label var e10_age_years_m_bl "Age"
label var d8_age_years_w_bl "Age"
label var e29_education_m_bl_clean "Years of education"
label var e11_education_w_bl_clean "Years of education"
label var civil_legal_marriage_bl "In a civil or legal marriage"
label var e12_n_bio_children_w_bl "No. of children"
label var own_gendernorms_w_bl "No. of gender inequitable attitudes"
label var own_gendernorms_m_bl "No. of gender inequitable attitudes" 
label var own_ipv_justified_w_bl "No. of reasons IPV is justified" 
label var own_ipv_justified_m_bl "No. of reasons IPV is justified"
label var cmty_beat_wife_low_bl "Thinks at most 25pc of men beat up wife"
label var cmty_force_sex_low_bl "Thinks at most 25pc of men force wife to have sex"
	
local balance emo_violence_dum_bl physical_violence_dum_bl sexual_violence_dum_bl d8_age_years_w_bl e11_education_w_bl_clean e12_n_bio_children_w_bl own_ipv_justified_w_bl own_gendernorms_w_bl e10_age_years_m_bl e29_education_m_bl_clean own_ipv_justified_m_bl own_gendernorms_m_bl cmty_beat_wife_low_bl cmty_force_sex_low_bl civil_legal_marriage_bl g1_meals_skipped_m_bl
iebaltab `balance' , grpvar(couple_type) savetex("$out/tables\tablea3.tex") replace  stats(pair(t)) rowvarlabel format(%9.2fc) vce(cluster village_id_m_num) fixedeffect(strata) ///
	tblnonote



*** Table A4: Treatment effects excluding respondents who live in unconfirmed or different village to VSLA-village of treatment assignment
	foreach var in $ipv {
		eststo clear
		eststo xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata if vill_notres==., cluster (village_id_m_bl)	
				outreg2 using "$out/tables/tablea4.tex", noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
				addtext(Baseline controls, YES)  keep(couple_treat spillover_couple) nonotes 
}


*** Table A5: Treatment effects excluding control couples living near treated and spillover couples
	foreach var in $ipv {
		forvalues n = 200(200)800 {
		eststo clear
		eststo xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata if ((couple_type == 0 & within`n'==0) | couple_type > 0), cluster (village_id_m_bl)	
				outreg2 using "$out/tables/tablea5.tex", noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
				addtext(Baseline controls, YES) append keep(couple_treat spillover_couple) nonotes  
		}
	}


*** Table A6: Spillover treatment-on-the-treated estimates- instrumenting spillovers’ village residence
label var village_treatment "Spillover couple assignment"
label var vill_actuallylived_was_t "Spillover couple complier"
preserve
	drop if couple_type==2
		foreach var in $ipv {
			eststo clear
			qui reg vill_actuallylived_was_t `var'_blmis `var'_bl_ancv village_treatment i.strata if `var' == 0 | `var' == 1, cluster (village_id_m_bl)	
					outreg2 using "$out/tables/tablea6.tex", noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
				addtext(Baseline controls, YES) keep(village_treatment) nonotes 
			qui ivregress 2sls `var'  `var'_blmis `var'_bl_ancv (vill_actuallylived_was_t=village_treatment) i.strata, 	first cluster (village_id_m_bl)	
					outreg2 using "$out/tables/tablea6.tex", noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
				addtext(Baseline controls, YES) keep(vill_actuallylived_was_t) nonotes 
	}
restore

*** Table A7: Treatment effects on IPV-related outcomes
	local related_out_a emo_contrl_behav_dum s17_injuries_minor s23_injuries_sex_w oo1_m2_signphyspain_w	
	local related_out_b emo_violence_m physical_violence_m 		
	local related_out_c knowledge_ipv_m_win knowledge_ipv_women_m_win		

	foreach var in `related_out_a' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea7_a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, YES) ///
			 keep(couple_treat spillover_couple) nonotes
	}
		eststo clear		
		eststo: xi: qui reg any_kid_phys_abuse_w couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum any_kid_phys_abuse_w if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea7_a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes

		eststo clear		
		eststo: xi: qui reg marital_disagreements_9_w couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum marital_disagreements_9_w if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea7_a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes

	foreach var in `related_out_b' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea7_b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')   addtext(Baseline controls, YES) ///
			 keep(couple_treat spillover_couple) nonotes
	}


	foreach var in `related_out_c' {
		eststo clear		
		eststo: xi: qui reg `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea7_b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')   addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes
	}


*** Table A8: Treatment effect on economic outcomes
	local eco_outa hh_assets_tot_num wife_assets_share business_involved_w business_involved_m
	local eco_outb savings_w_win savings_m_win 
	
	foreach var in `eco_outa' {
		eststo clear		
		eststo: xi: qui reg `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea8.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes
	}
	foreach var in `eco_outb' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea8.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES) ///
			 keep(couple_treat spillover_couple) nonotes
	}


*** Table A9: Heterogeneous effects by baseline violence

foreach var in $ipv {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple no_vio_bl_treat no_vio_bl_spill no_vio_bl i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat + no_vio_bl_treat
			local	pval1=	r(p)			
			lincom spillover_couple + no_vio_bl_spill
			local	pval2=	r(p)		
			outreg2  using "$out/tables/tablea9.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("P-value (Treated + Treated * no violence = 0)", `pval1',"P-value (Spillover + Spillover * no violence = 0)", `pval2' ) ///
			 addtext(Baseline controls, YES) keep(couple_treat spillover_couple no_vio*) nonotes
}

*** Table A10: Treatment effect by IPV question 
	local ipv_questiona public_humiliation_w insult_w
	local ipv_questionb slapped_w twisted_arm_w punched_w beaten_w strangled_w attacked_wpn_w	
	local ipv_questionc forced_sex_w forced_sex_fear_w degrd_sex_w

foreach var in `ipv_questiona' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea10_a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			 keep(couple_treat spillover_couple) nonotes
	}
	foreach var in `ipv_questionb' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea10_b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			 keep(couple_treat spillover_couple) nonotes
	}
	foreach var in `ipv_questionc' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea10_c.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			 keep(couple_treat spillover_couple) nonotes
	}

*** Table A11: Increase in frequency and number of types of IPV
	local ipv_freqa slapped_w_sof twisted_arm_w_sof punched_w_sof beaten_w_sof strangled_w_sof attacked_wpn_w_sof  	
	local ipv_freqb forced_sex_w_sof forced_sex_fear_w_sof degrd_sex_w_sof 
	local ipv_freqc emo_vio_numb phys_vio_numb sex_vio_numb

foreach var in `ipv_freqa' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea11_a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			 keep(couple_treat spillover_couple) nonotes
	}
	foreach var in `ipv_freqb' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea11_b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			 keep(couple_treat spillover_couple) nonotes
	}
	foreach var in `ipv_freqc' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea11_c.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			 keep(couple_treat spillover_couple) nonotes
	}


*** Table A12: Treatment effect on refusal to answer at least one IPV-related question

	local refusal_answer emo_vio_ref phys_vio_ref sex_vio_ref
		foreach var in `refusal_answer' {
		eststo clear		
		eststo: xi: qui reg  `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea12.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1') addtext(Baseline controls, YES)  ///
			  keep(couple_treat spillover_couple) nonotes
	}


*** Table A13: Treatment effects on indicators of stigma and empowerment to report
	label var ipv_report_2_w_cln " "
	local stigma safe_space_visit_w s24_violence_talked_w ipv_report_2_w_cln safe_space_visit_m

		foreach var in `stigma' {
		eststo clear		
		eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea13.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, NO)  ///
			  keep(couple_treat spillover_couple) nonotes
	}


*** Table A14: Correlations between women's IPV experience and potentially objective indicators
local corr_objective emo_violence_dum physical_violence_dum sexual_violence_dum oo1_meta1_distress_w oo1_m2_signphyspain_w oo5_m5_cnsl_refer_w_all oo6_m6_spk_cnsl_w

eststo clear 
	estpost correlate `corr_objective', matrix listwise
	esttab using "$out/tables/tablea14.tex", unstack not compress b(2) label replace



*** Table A15: Heterogeneous effects by husband migration status

foreach var in $ipv {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple mig_treat mig_spill mig i.strata,  vce(cluster village_id_m_bl)  	
		lincom couple_treat + mig_treat
			local	pval1=	r(p)			
			lincom spillover_couple + mig_spill
			local	pval2=	r(p)		
			outreg2  using "$out/tables/tablea15.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("P-value (Treated + Treated * Husband worked away = 0)", `pval1',"P-value (Spillover + Spillover * Husband worked away = 0)", `pval2' ) ///
			 addtext(Baseline controls, YES)   keep(couple_treat spillover_couple mig*) nonotes
}



*** Table A16: Impact on descriptive norms: beliefs about IPV attitudes and prevalence in the community
local cmty_attitudesa  WeightedVar_norms_w z2_cmty_obey_husband_w z5_cmnty_jealousy_w z6_cmty_beat_wife_w z7_cmty_force_sex_w	
local cmty_attitudesb WeightedVar_norms_m dd2_cmty_obey_husband_m dd5_cmnty_jealousy_m dd7_cmty_beat_wife_m dd8_cmty_force_sex_m
	
	foreach var in `cmty_attitudesa' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea16_a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(Baseline controls, YES)  ///
			   keep(couple_treat spillover_couple) nonotes
	}
	foreach var in `cmty_attitudesb' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum `var' if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$out/tables/tablea16_b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')   addtext(Baseline controls, YES)  ///
			  keep(couple_treat spillover_couple) nonotes
	}


*** Table A17: Heterogeneous treatment effects by husband's baseline mental wellbeing indicators
foreach int in trauma_score_m_bl aa12_fth_phipv_m_bl_dm {
	replace inter = `int'
	replace	int_treat = `int' * couple_treat
	replace int_spill = `int' * spillover_couple 

	foreach var in $ipv {
			eststo clear		
			eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple int_treat int_spill inter i.strata,  vce(cluster village_id_m_bl)  
				outreg2  using "$out/tables/tablea17.tex" , append noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
			 addtext(Baseline controls, YES)  keep(couple_treat spillover_couple int*) nonotes		
	}
}


*** Table A18: Additional specifications: Single difference, with controls, and probit

* First difference
	foreach var in emo_violence_fd physical_violence_fd sexual_violence_fd {
		eststo: xi: qui reg `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
			outreg2  using "$out/tables/tablea18.tex" , append noquote label tex(frag) nodepvar dec(2)  nocons nor2 ///
			 addtext(Baseline controls, NO)  keep(couple_treat spillover_couple) nonotes
	}

* PDS Lasso
	
	rename q2_beating_refusing_sex_w_bl_p q2_w_bl_p_m
	rename q5_beat_suspect_unfaith_w_bl_p q5_w_bl_p
	rename dd1_cmty_shame_hhwrk_m_bl_ancv dd1_m_bl_m
	rename dd2_cmty_obey_husband_m_bl_ancv dd2_m_bl
	rename oo7_sdm7_tokens_give_m_bl_ancv oo7_sdm7_tokens_m_bl
	rename dd6_cmty_prohib_vist_m_bl_ancv dd6_m_bl
	rename k7_woman_control_man_m_bl_ancv k7_m_bl
	rename l1_conflict_resolution_m_bl_ancv l1_m_bl_ancv
	rename l1_conflict_resolution_m_blmis l1_m_bl_mis
	rename ll1_sdm7_tokens_give_w_bl_ancv ll1_w_bl
	
	eststo clear			
		local lasso i.strata emo_violence_dum_blmis emo_violence_dum_bl_ancv ///
		physical_violence_dum_blmis physical_violence_dum_bl_ancv sexual_violence_dum_blmis sexual_violence_dum_bl_ancv WeightedVar_beat_likl_m_bl  d8_age_years_w_bl d5_partner_title1_w_bl ///
		l3_partner_trust2_m_bl m3_partner_trust2_w_bl dep_score_m_ancv dep_score_mmis t1_ptnr_alcl_use_w_blmis  t1_ptnr_alcl_use_w_bl_ancv ptnr_drnktoomuch_w_blmis ptnr_drnktoomuch_w_bl_ancv ///
		alc_excess_m_blmis alc_excess_m_bl_ancv gg8_rel_talks_num_m_bl gg4_rel_blood_num_m_bl own_gendernorms_w_equit_bl unable_to_work_w_bl sector_id Napplicantscat ///
		q1_beat_neglect_child_w_bl_p /*q2_beating_refusing_sex_w_bl_p*/ q2_w_bl_p_m q3_beating_disobey_w_bl_p q4_beating_burn_food_w_bl_p /*q5_beat_suspect_unfaith_w_bl_p*/ q5_w_bl_p own_gendernorms_w_bl own_ipv_justified_w_blmis own_ipv_justified_w_bl_ancv own_refusesex_w_blmis own_refusesex_w_bl_ancv ///
		numb_villagerels_w_bl numb_closefriends_w_bl numb_villagerels_m_bl numb_closefriends_m_bl e29_education_m_bl_clean e11_education_w_bl_clean ///
		vmn_own_gendernorms_w_bl l3_partner_trust2_m_bl h2_paid_employed_m_bl e15_concubines_m_bl e10_age_years_m_bl e9_household_size_m_bl  ///
		dep_total_score_m_blmis dep_total_score_m_bl_ancv become_intimidating_m_blmis become_intimidating_m_bl_ancv intent_violence_m_blmis intent_violence_m_bl_ancv ///
		trauma_score_m_blmis trauma_score_m_bl_ancv own_ipv_justified_m_blmis own_ipv_justified_m_bl_ancv own_refusesex_m_blmis own_refusesex_m_bl_ancv ///
		oo7_sdm7_tokens_give_m_blmis /*oo7_sdm7_tokens_give_m_bl_ancv*/ oo7_sdm7_tokens_m_bl dd1_cmty_shame_hhwrk_m_blmis /*dd1_cmty_shame_hhwrk_m_bl_ancv*/ dd1_m_bl_m dd2_cmty_obey_husband_m_blmis /*dd2_cmty_obey_husband_m_bl_ancv*/ dd2_m_bl ///
		dd3_cmty_womcontl_m_blmis dd3_cmty_womcontl_m_bl_ancv dd4_cmty_noin_m_blmis dd4_cmty_noin_m_bl_ancv dd5_cmnty_jealousy_m_blmis dd5_cmnty_jealousy_m_bl_ancv ///
		dd6_cmty_prohib_vist_m_blmis /*dd6_cmty_prohib_vist_m_bl_ancv*/ dd6_m_bl dd7_cmty_beat_wife_m_blmis dd7_cmty_beat_wife_m_bl_ancv dd8_cmty_force_sex_m_blmis dd8_cmty_force_sex_m_bl_ancv ///
		k6_obey_husband_m_blmis k6_obey_husband_m_bl_ancv k7_woman_control_man_m_blmis /*k7_woman_control_man_m_bl_ancv*/ k7_m_bl k8_ipv_private_m_blmis k8_ipv_private_m_bl_ancv ///
		/*l1_conflict_resolution_m_blmis*/ l1_m_bl_mis /*l1_conflict_resolution_m_bl_ancv*/ l1_m_bl_ancv l2_emotion_sharing_m_blmis l2_emotion_sharing_m_bl_ancv l3_partner_trust2_m_blmis l3_partner_trust2_m_bl_ancv ///
		h2_paid_employed_m_blmis h2_paid_employed_m_bl_ancv e15_concubines_m_blmis e15_concubines_m_bl_ancv e10_age_years_m_blmis e10_age_years_m_bl_ancv ///
		e9_household_size_m_blmis e9_household_size_m_bl_ancv ll1_sdm7_tokens_give_w_blmis /*ll1_sdm7_tokens_give_w_bl_ancv*/ ll1_w_bl i1_vsla_ptcp_yrs_w_blmis i1_vsla_ptcp_yrs_w_bl_ancv

			* Emotional violence controls
		qui pdslasso emo_violence_dum couple_treat spillover_couple (`lasso'), cluster(village_id_m_bl) fe partial(i.strata emo_violence_dum_blmis emo_violence_dum_bl_ancv) 
		local control1 = e(xselected)
		eststo xi: reg emo_violence_dum emo_violence_dum_blmis emo_violence_dum_bl_ancv couple_treat spillover_couple `control1' i.strata,  vce(cluster village_id_m_bl)  
			outreg2  using "$out/tables/tablea18.tex" , append noquote label tex(frag) nodepvar dec(2)  nocons nor2 ///
			 addtext(Baseline controls, YES)  keep(couple_treat spillover_couple) nonotes

			* Physical violence controls
		qui pdslasso physical_violence_dum couple_treat spillover_couple (`lasso'), cluster(village_id_m_bl) fe partial(i.strata physical_violence_dum_blmis physical_violence_dum_bl_ancv) 
		local control2 = e(xselected)
		eststo xi: reg physical_violence_dum physical_violence_dum_blmis physical_violence_dum_bl_ancv couple_treat spillover_couple `control2' i.strata,  vce(cluster village_id_m_bl)  
			outreg2  using "$out/tables/tablea18.tex" , append noquote label tex(frag) nodepvar dec(2)  nocons nor2 ///
			 addtext(Baseline controls, YES)  keep(couple_treat spillover_couple) nonotes
	
			* Sexual violence controls
		qui pdslasso sexual_violence_dum couple_treat spillover_couple (`lasso'), cluster(village_id_m_bl) fe partial(i.strata sexual_violence_dum_blmis sexual_violence_dum_bl_ancv) 
		local control3 = e(xselected)
		eststo xi: reg sexual_violence_dum sexual_violence_dum_blmis sexual_violence_dum_bl_ancv couple_treat spillover_couple `control3' i.strata,  vce(cluster village_id_m_bl)  
			outreg2  using "$out/tables/tablea18.tex" , append noquote label tex(frag) nodepvar dec(2)  nocons nor2 ///
			 addtext(Baseline controls, YES)  keep(couple_treat spillover_couple) nonotes

* Probit
	foreach var in $ipv {
		eststo clear
		eststo xi: qui probit `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata, vce(cluster village_id_m_bl)	  
			outreg2  using "$out/tables/tablea18.tex" , append noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
			 addtext(Baseline controls, YES)  keep(couple_treat spillover_couple) nonotes
			}

*** Table A19: Additional specifications: IV treatment-on-the-treated
label var couple_treat "Treated couple assignment"
label var actual_couple_treatment "Treated couple complier"
	foreach var in $ipv {
		eststo clear
		qui reg actual_couple_treatment `var'_blmis `var'_bl_ancv couple_treat spillover_couple i.strata if `var' == 0 | `var' == 1, cluster (village_id_m_bl)	
				outreg2 using "$out/tables/tablea19.tex", noquote label tex(frag) nodepvar dec(2) nocons nor2  addtext(Baseline controls, YES)  keep(couple_treat spillover_couple) nonotes 
		qui ivregress 2sls `var' `var'_blmis `var'_bl_ancv spillover_couple (actual_couple_treatment=couple_treat) i.strata, 	first cluster (village_id_m_bl)	
				outreg2 using "$out/tables/tablea19.tex", noquote label tex(frag) nodepvar dec(2) nocons nor2  addtext(Baseline controls, YES)  keep(actual_couple_treatment spillover_couple) nonotes 
}
label var couple_treat "Treated couple"


*** Table A20: Recoding missing refuse-to-answer violence questions as ‘yes’ and ‘no’

	local tablea24 emo_vio_act_refeqlyes emo_vio_act_refeqlno phys_vio_refeqlyes phys_vio_refeqlno sex_vio_act_refeqlyes sex_vio_act_refeqlno
	foreach var in `tablea24' {
		eststo clear
		eststo xi: qui reg `var' `var'_bl couple_treat spillover_couple i.strata, vce(cluster village_id_m_bl)	  
			outreg2  using "$out/tables/tablea20.tex" , append noquote label tex(frag) nodepvar dec(2) nocons nor2 ///
			addtext(Baseline controls, YES) keep(couple_treat spillover_couple) nonotes
	}

*** Figure A1: How ‘pure’ are pure control couples? Number of treated couples living within various distances of couples.

forvalues n = 200(200)1000{ 
	distplot  within`n'	, over(couple_type) xtitle("Number of trained couples" "living within `n' meters from respondent") ytitle(empirical c.d.f.) ///	
		lp(solid dash dot) lcolor(gs0 gs0 gs0) legend(off) graphregion(color(white))
		graph export "$out/figures/figurea1_`n'.png", replace
}
	distplot  within200	, over(couple_type) xtitle("Number of trained couples" "living within 200 meters from respondent") ytitle(empirical c.d.f.) ///	
		lp(solid dash dot) lcolor(gs0 gs0 gs0) legend(row(3) label(1 "Control") label(2 "Spillovers") label(3 "Treated")) graphregion(color(white))
		graph export "$out/figures/figurea1_200_leg.png", replace






